/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.callcontext;

import static de.ozgcloud.vorgang.callcontext.CallContextHandleInterceptor.*;
import static de.ozgcloud.vorgang.callcontext.UserTestFactory.*;

import java.util.UUID;

import de.ozgcloud.common.grpc.GrpcUtil;
import io.grpc.Metadata;

public class CallContextTestFactory {

	public static final User USER = UserTestFactory.create();
	public static final String CLIENT = "testclient-0817";

	public static final String REQUEST_ID = UUID.randomUUID().toString();
	public static final Boolean DO_ORGA_ID_ACCESS_CHECK = Boolean.TRUE;

	public static CallContext create() {
		return createBuilder().build();
	}

	public static CallContext.CallContextBuilder createBuilder() {
		return CallContext.builder()
				.user(USER)
				.client(CLIENT);
	}

	public static Metadata createMetadata() {
		var result = new Metadata();
		result.put(GrpcUtil.HEADER_KEY_USER_ID, ID.getBytes());
		result.put(GrpcUtil.createKeyOf(KEY_USER_NAME), NAME.getBytes());
		result.put(GrpcUtil.createKeyOf(KEY_CLIENT_NAME), CLIENT.getBytes());
		result.put(GrpcUtil.createKeyOf(KEY_ACCESS_LIMITED_ORGAID), ORGANISATORISCHE_EINHEITEN_ID.getBytes());
		result.put(GrpcUtil.createKeyOf(KEY_REQUEST_ID), REQUEST_ID.getBytes());
		result.put(GrpcUtil.createKeyOf(KEY_ACCESS_LIMITED), DO_ORGA_ID_ACCESS_CHECK.toString().getBytes());

		return result;
	}

}
