/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.callcontext;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.springframework.security.authentication.AuthenticationTrustResolver;
import org.springframework.security.core.context.SecurityContextHolder;

class CurrentUserServiceTest {

	@InjectMocks
	private CurrentUserService service;

	@Mock
	private AuthenticationTrustResolver trustResolver;
	@Mock
	private CallContextAuthenticationToken mockAuthentication;

	@BeforeEach
	void mockAuthentication() {
		when(trustResolver.isAnonymous(any())).thenReturn(false);
		when(mockAuthentication.isAuthenticated()).thenReturn(true);

		SecurityContextHolder.getContext().setAuthentication(mockAuthentication);
	}

	@Nested
	class TestFindUser {
		@Test
		void shouldReturnUser() {
			when(mockAuthentication.getPrincipal()).thenReturn(CallContextUserTestFactory.create());

			var auth = service.findUser();

			assertThat(auth).isPresent();
		}

		@Test
		void shouldReturnNonOnMissingClientName() {
			when(mockAuthentication.getPrincipal()).thenReturn(CallContextUserTestFactory.createBuilder().clientName(null).build());

			var auth = service.findUser();

			assertThat(auth).isEmpty();
		}
	}

}
