/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.callcontext;

import de.ozgcloud.common.grpc.GrpcUtil;
import io.grpc.CallOptions;
import io.grpc.Channel;
import io.grpc.ClientCall;
import io.grpc.ClientInterceptor;
import io.grpc.ForwardingClientCall.SimpleForwardingClientCall;
import io.grpc.Metadata;
import io.grpc.MethodDescriptor;
import lombok.Setter;

@Setter
public class TestCallContextAttachingInterceptor implements ClientInterceptor {

	private final String clientName = CallContextTestFactory.CLIENT;
	private final String organisationEinheitId = UserTestFactory.ORGANISATORISCHE_EINHEITEN_ID;
	private final Boolean organisationEinheitIdCheckNecessary = Boolean.TRUE;

	@Override
	public <ReqT, RespT> ClientCall<ReqT, RespT> interceptCall(MethodDescriptor<ReqT, RespT> method, CallOptions callOptions, Channel next) {
		return new TestCallContextAttachingClientCall<>(next.newCall(method, callOptions));
	}

	final class TestCallContextAttachingClientCall<ReqT, RespT> extends SimpleForwardingClientCall<ReqT, RespT> {

		private TestCallContextAttachingClientCall(ClientCall<ReqT, RespT> delegate) {
			super(delegate);
		}

		@Override
		public void start(Listener<RespT> responseListener, Metadata headers) {
			var metadata = new Metadata();
			metadata.put(GrpcUtil.createKeyOf(CallContextHandleInterceptor.KEY_CLIENT_NAME), clientName.getBytes());
			metadata.put(GrpcUtil.HEADER_KEY_USER_ID, UserTestFactory.ID.getBytes());
			metadata.put(GrpcUtil.createKeyOf(CallContextHandleInterceptor.KEY_ACCESS_LIMITED_ORGAID), organisationEinheitId.getBytes());
			metadata.put(GrpcUtil.createKeyOf(CallContextHandleInterceptor.KEY_ACCESS_LIMITED),
					organisationEinheitIdCheckNecessary.toString().getBytes());

			headers.merge(metadata);

			super.start(responseListener, headers);
		}
	}
}
